@@ -8,8 +8,9 @@ use Test::Builder;
 use UNIVERSAL::require;
 use Test::Compile::Internal;
 
-our $VERSION = '0.21';
+our $VERSION = '0.22';
 my $Test = Test::Compile::Internal->new();
+_verbose(1);
 
 =head1 NAME
 
@@ -222,6 +223,10 @@ sub all_pl_files {
     return $Test->all_pl_files(@_);
 }
 
+sub _verbose {
+    return $Test->verbose(@_);
+}
+
 1;
 
 =head1 AUTHORS
